#!/usr/bin/env python

#-----------------------------------------------------------------------
# orderprep.py
# Author: Bob Dondero
#-----------------------------------------------------------------------

import os
import sys
import psycopg2
import dotenv

dotenv.load_dotenv()
DATABASE_URL = os.environ['DATABASE_URL']

#-----------------------------------------------------------------------


def main():

    if len(sys.argv) != 3:
        print('Usage: python ' + sys.argv[0] + ' isbn custid',
            file=sys.stderr)
        sys.exit(1)

    isbn = sys.argv[1]
    custid = sys.argv[2]

    try:
        with psycopg2.connect(DATABASE_URL) as connection:

            with connection.cursor() as cursor:

                stmt_str = "UPDATE orders SET quantity = quantity+1 "
                stmt_str += "WHERE isbn = %s AND custid = %s"
                cursor.execute(stmt_str, [isbn, custid])

    except Exception as ex:
        print(ex, file=sys.stderr)
        sys.exit(1)

#-----------------------------------------------------------------------

if __name__ == '__main__':
    main()
